@@ -1,7 +1,7 @@
+import autogalaxy as ag
 from autoarray.plot import plotters
-from autoarray.plot import mat_objs
-from autoastro.plot import lensing_plotters
-from autolens.plot import plane_plots
+from autoarray.structures import arrays
+from autogalaxy.plot import lensing_plotters
 
 
 @lensing_plotters.set_include_and_sub_plotter
@@ -29,7 +29,7 @@ def subplot_tracer(tracer, grid, positions=None, include=None, sub_plotter=None)
 
     sub_plotter.setup_subplot(number_subplots=number_subplots, subplot_index=1)
 
-    profile_image(
+    image(
         tracer=tracer,
         grid=grid,
         positions=positions,
@@ -51,7 +51,7 @@ def subplot_tracer(tracer, grid, positions=None, include=None, sub_plotter=None)
 
     source_plane_grid = tracer.traced_grids_of_planes_from_grid(grid=grid)[-1]
 
-    plane_plots.plane_image(
+    ag.plot.Plane.plane_image(
         plane=tracer.source_plane,
         grid=source_plane_grid,
         caustics=include.caustics_from_obj(obj=tracer),
@@ -78,7 +78,7 @@ def individual(
     tracer,
     grid,
     positions=None,
-    plot_profile_image=False,
+    plot_image=False,
     plot_source_plane=False,
     plot_convergence=False,
     plot_potential=False,
@@ -106,9 +106,9 @@ def individual(
     if include is None:
         include = lensing_plotters.Include()
 
-    if plot_profile_image:
+    if plot_image:
 
-        profile_image(
+        image(
             tracer=tracer,
             grid=grid,
             positions=positions,
@@ -128,7 +128,7 @@ def individual(
 
         source_plane_grid = tracer.traced_grids_of_planes_from_grid(grid=grid)[-1]
 
-        plane_plots.plane_image(
+        ag.plot.Plane.plane_image(
             plane=tracer.source_plane,
             grid=source_plane_grid,
             caustics=include.caustics_from_obj(obj=tracer),
@@ -150,19 +150,15 @@ def individual(
 
 @lensing_plotters.set_include_and_plotter
 @plotters.set_labels
-def profile_image(tracer, grid, positions=None, include=None, plotter=None):
+def image(tracer, grid, positions=None, include=None, plotter=None):
 
     plotter.plot_array(
-        array=tracer.profile_image_from_grid(grid=grid),
+        array=tracer.image_from_grid(grid=grid),
         mask=include.mask_from_grid(grid=grid),
         positions=positions,
         critical_curves=include.critical_curves_from_obj(obj=tracer),
-        light_profile_centres=include.light_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
-        mass_profile_centres=include.mass_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
+        light_profile_centres=include.light_profile_centres_from_obj(obj=tracer),
+        mass_profile_centres=include.mass_profile_centres_from_obj(obj=tracer),
         include_origin=include.origin,
     )
 
@@ -175,12 +171,8 @@ def convergence(tracer, grid, include=None, plotter=None):
         array=tracer.convergence_from_grid(grid=grid),
         mask=include.mask_from_grid(grid=grid),
         critical_curves=include.critical_curves_from_obj(obj=tracer),
-        light_profile_centres=include.light_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
-        mass_profile_centres=include.mass_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
+        light_profile_centres=include.light_profile_centres_from_obj(obj=tracer),
+        mass_profile_centres=include.mass_profile_centres_from_obj(obj=tracer),
         include_origin=include.origin,
     )
 
@@ -193,12 +185,8 @@ def potential(tracer, grid, include=None, plotter=None):
         array=tracer.potential_from_grid(grid=grid),
         mask=include.mask_from_grid(grid=grid),
         critical_curves=include.critical_curves_from_obj(obj=tracer),
-        light_profile_centres=include.light_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
-        mass_profile_centres=include.mass_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
+        light_profile_centres=include.light_profile_centres_from_obj(obj=tracer),
+        mass_profile_centres=include.mass_profile_centres_from_obj(obj=tracer),
         include_origin=include.origin,
     )
 
@@ -208,20 +196,16 @@ def potential(tracer, grid, include=None, plotter=None):
 def deflections_y(tracer, grid, include=None, plotter=None):
 
     deflections = tracer.deflections_from_grid(grid=grid)
-    deflections_y = grid.mapping.array_stored_1d_from_sub_array_1d(
-        sub_array_1d=deflections[:, 0]
+    deflections_y = arrays.MaskedArray.manual_1d(
+        array=deflections.in_1d[:, 0], mask=grid.mask
     )
 
     plotter.plot_array(
         array=deflections_y,
         mask=include.mask_from_grid(grid=grid),
         critical_curves=include.critical_curves_from_obj(obj=tracer),
-        light_profile_centres=include.light_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
-        mass_profile_centres=include.mass_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
+        light_profile_centres=include.light_profile_centres_from_obj(obj=tracer),
+        mass_profile_centres=include.mass_profile_centres_from_obj(obj=tracer),
         include_origin=include.origin,
     )
 
@@ -231,20 +215,16 @@ def deflections_y(tracer, grid, include=None, plotter=None):
 def deflections_x(tracer, grid, include=None, plotter=None):
 
     deflections = tracer.deflections_from_grid(grid=grid)
-    deflections_x = grid.mapping.array_stored_1d_from_sub_array_1d(
-        sub_array_1d=deflections[:, 1]
+    deflections_x = arrays.MaskedArray.manual_1d(
+        array=deflections.in_1d[:, 1], mask=grid.mask
     )
 
     plotter.plot_array(
         array=deflections_x,
         mask=include.mask_from_grid(grid=grid),
         critical_curves=include.critical_curves_from_obj(obj=tracer),
-        light_profile_centres=include.light_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
-        mass_profile_centres=include.mass_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
+        light_profile_centres=include.light_profile_centres_from_obj(obj=tracer),
+        mass_profile_centres=include.mass_profile_centres_from_obj(obj=tracer),
         include_origin=include.origin,
     )
 
@@ -257,12 +237,8 @@ def magnification(tracer, grid, include=None, plotter=None):
         array=tracer.magnification_from_grid(grid=grid),
         mask=include.mask_from_grid(grid=grid),
         critical_curves=include.critical_curves_from_obj(obj=tracer),
-        light_profile_centres=include.light_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
-        mass_profile_centres=include.mass_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
+        light_profile_centres=include.light_profile_centres_from_obj(obj=tracer),
+        mass_profile_centres=include.mass_profile_centres_from_obj(obj=tracer),
         include_origin=include.origin,
     )
 
@@ -276,11 +252,7 @@ def contribution_map(tracer, mask=None, positions=None, include=None, plotter=No
         mask=mask,
         positions=positions,
         critical_curves=include.critical_curves_from_obj(obj=tracer),
-        light_profile_centres=include.light_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
-        mass_profile_centres=include.mass_profile_centres_of_planes_from_obj(
-            obj=tracer
-        ),
+        light_profile_centres=include.light_profile_centres_from_obj(obj=tracer),
+        mass_profile_centres=include.mass_profile_centres_from_obj(obj=tracer),
         include_origin=include.origin,
     )
