@@ -1,10 +1,8 @@
 import time
 
 import autolens as al
-
-from test_autolens.simulate.imaging import simulate_util
-
 import numpy as np
+from test_autolens.simulate.imaging import simulate_util
 
 repeats = 10
 
@@ -24,7 +22,7 @@ print("pixelization shape = " + str(pixelization_shape_2d) + "\n")
 lens_galaxy = al.Galaxy(
     redshift=0.5,
     mass=al.mp.EllipticalIsothermal(
-        centre=(0.0, 0.0), einstein_radius=1.6, axis_ratio=0.7, phi=45.0
+        centre=(0.0, 0.0), einstein_radius=1.6, elliptical_comps=(0.17647, 0.0)
     ),
 )
 
@@ -36,11 +34,11 @@ source_galaxy = al.Galaxy(
     regularization=al.reg.Constant(coefficient=1.0),
 )
 
-for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
+for instrument in ["vro", "euclid", "hst", "hst_up"]:  # , 'ao']:
 
     imaging = simulate_util.load_test_imaging(
-        data_type="lens_sie__source_smooth",
-        data_resolution=data_resolution,
+        data_name="lens_sie__source_smooth",
+        instrument=instrument,
         psf_shape_2d=psf_shape_2d,
     )
 
@@ -53,9 +51,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
 
     masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask)
 
-    print(
-        "Rectangular Inversion fit run times for image type " + data_resolution + "\n"
-    )
+    print("Rectangular Inversion fit run times for image type " + instrument + "\n")
     print("Number of points = " + str(masked_imaging.grid.sub_shape_1d) + "\n")
 
     start_overall = time.time()
@@ -103,7 +99,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
 
     start = time.time()
     for i in range(repeats):
-        data_vector = al.util.inversion.data_vector_from_blurred_mapping_matrix_and_data(
+        data_vector = al.util.inversion.data_vector_via_blurred_mapping_matrix_from(
             blurred_mapping_matrix=blurred_mapping_matrix,
             image=masked_imaging.image,
             noise_map=masked_imaging.noise_map,
@@ -113,7 +109,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
 
     start = time.time()
     for i in range(repeats):
-        curvature_matrix = al.util.inversion.curvature_matrix_from_blurred_mapping_matrix(
+        curvature_matrix = al.util.inversion.curvature_matrix_via_blurred_mapping_matrix_from(
             blurred_mapping_matrix=blurred_mapping_matrix,
             noise_map=masked_imaging.noise_map,
         )
@@ -122,7 +118,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
 
     start = time.time()
     for i in range(repeats):
-        regularization_matrix = al.util.regularization.constant_regularization_matrix_from_pixel_neighbors(
+        regularization_matrix = al.util.regularization.constant_regularization_matrix_from(
             coefficient=1.0,
             pixel_neighbors=mapper.pixelization_grid.pixel_neighbors,
             pixel_neighbors_size=mapper.pixelization_grid.pixel_neighbors_size,
@@ -144,7 +140,7 @@ for data_resolution in ["lsst", "euclid", "hst", "hst_up"]:  # , 'ao']:
 
     start = time.time()
     for i in range(repeats):
-        al.util.inversion.mapped_reconstructed_data_from_mapping_matrix_and_reconstruction(
+        al.util.inversion.mapped_reconstructed_data_from(
             mapping_matrix=blurred_mapping_matrix, reconstruction=reconstruction
         )
     diff = time.time() - start
